@@ -48,12 +48,12 @@
 #endif  // _WIN32 || defined(_WIN16)
 
 // ***** Unix variations
-#if defined(__linux__) && !defined(NV_LINUX)
+#if defined(__linux__) && !defined(NV_LINUX) && !defined(NV_VMWARE)
 #   define NV_LINUX
 #endif  // defined(__linux__)
 
 // SunOS + gcc
-#if defined(__sun__) && defined(__svr4__)
+#if defined(__sun__) && defined(__svr4__) && !defined(NV_SUNOS)
 #   define NV_SUNOS
 #endif // defined(__sun__) && defined(__svr4__)
 
@@ -61,11 +61,9 @@
 #if defined(__SUNPRO_C) || defined(__SUNPRO_CC)
 #   define NV_SUNPRO_C
 #   define NV_SUNOS
-#   define  __FUNCTION__ __func__
-#   define NV_OPENGL_THREAD_UNSAFE // XXX To start with
 #endif // defined(_SUNPRO_C) || defined(__SUNPRO_CC)
 
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) && !defined(NV_BSD)
 #   define NV_BSD
 #endif // defined(__FreeBSD__)
 
@@ -148,6 +146,9 @@
 #   ifndef NVCPU_SH4
 #   define NVCPU_SH4               // Renesas (formerly Hitachi) SH4
 #   endif
+#   if   defined NV_WINDOWS_CE
+#       define NVCPU_MIN_PAGE_SHIFT 12
+#   endif
 #endif
 
 // For Xtensa processors
@@ -186,7 +187,7 @@
 #endif
 
 // For verification-only features not intended to be included in normal drivers
-#if defined(NV_MODS) && defined(DEBUG) && !defined(NV_DOS)
+#if defined(NV_MODS) && defined(DEBUG) && !defined(NV_DOS) && !defined(VISTA_MFG_MODS) && !defined(LINUX_MFG)
 #define NV_VERIF_FEATURES
 #endif
 
