@@ -539,6 +539,22 @@
 #define __NV_MAP_REGISTERS_EARLY MapRegistersEarly
 #define NV_REG_MAP_REGISTERS_EARLY NV_REG_STRING(__NV_MAP_REGISTERS_EARLY)
 
+/*
+ * Option: RegisterForACPIEvents
+ *
+ * Description:
+ *
+ * When this option is enabled the NVIDIA driver will register with the ACPI
+ * subsystems to receive ACPI events.
+ *
+ * Possible values:
+ * 1 - register for ACPI events (default)
+ * 0 - do not register for ACPI events
+ */
+
+#define __NV_REGISTER_FOR_ACPI_EVENTS  RegisterForACPIEvents
+#define NV_REG_REGISTER_FOR_ACPI_EVENTS NV_REG_STRING(__NV_REGISTER_FOR_ACPI_EVENTS)
+
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
 /* 
@@ -564,6 +580,7 @@ NV_DEFINE_REG_ENTRY(__NV_RM_EDGE_INTR_CHECK, 1);
 NV_DEFINE_REG_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE, ~0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 0);
 NV_DEFINE_REG_ENTRY(__NV_MAP_REGISTERS_EARLY, 0);
+NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
 
 #if defined(NV_LINUX)
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
@@ -612,6 +629,7 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_PAGE_ATTRIBUTE_TABLE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_MSI),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MAP_REGISTERS_EARLY),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS),
     {NULL, NULL, NULL}
 };
 
