@@ -80,10 +80,12 @@ typedef struct nv_ioctl_xfer
 typedef struct nv_ioctl_card_info
 {
     NvU16    flags;               /* see below                   */
+    NvU32    domain;              /* PCI domain number           */
     NvU8     bus;                 /* bus number (PCI, AGP, etc)  */
     NvU8     slot;                /* card slot                   */
     NvU16    vendor_id;           /* PCI vendor id               */
     NvU16    device_id;
+    NvU32    gpu_id;
     NvU16    interrupt_line;
     NvU64    reg_address    NV_ALIGN_BYTES(8);
     NvU64    reg_size       NV_ALIGN_BYTES(8);
@@ -153,6 +155,7 @@ typedef struct nv_ioctl_free_os_event
 /* status code */
 typedef struct nv_ioctl_status_code
 {
+    NvU32 domain;
     NvU32 bus;
     NvU32 slot;
     NvU32 status;
@@ -268,11 +271,13 @@ typedef struct
     int    flags;
 
     /* PCI config info */
+    NvU32 domain;
     NvU16 bus;
     NvU16 slot;
     NvU16 vendor_id;
     NvU16 device_id;
     NvU16 subsystem_id;
+    NvU32 gpu_id;
     void *handle;
 
     NvU32 pci_cfg_space[16];
@@ -304,6 +309,7 @@ typedef struct
 typedef struct
 {
     /* PCI config info */
+    NvU32 domain;
     NvU16 bus;
     NvU16 slot;
     NvU16 vendor_id;
@@ -317,17 +323,18 @@ typedef struct
  * flags
  */
 
-#define NV_FLAG_OPEN            0x0001
-#define NV_FLAG_WAS_POSTED      0x0002
-#define NV_FLAG_CONTROL         0x0004
-#define NV_FLAG_MAP_REGS_EARLY  0x0008
-#define NV_FLAG_USE_BAR0_CFG    0x0010
-#define NV_FLAG_USES_MSI        0x0020
-#define NV_FLAG_S4_AVAILABLE    0x0040
-#define NV_FLAG_PASSTHRU        0x0080
-#define NV_FLAG_GVI_IN_SUSPEND  0x0100
-#define NV_FLAG_GVI             0x0200
-#define NV_FLAG_GVI_INTR_EN     0x0400
+#define NV_FLAG_OPEN                   0x0001
+#define NV_FLAG_WAS_POSTED             0x0002
+#define NV_FLAG_CONTROL                0x0004
+#define NV_FLAG_MAP_REGS_EARLY         0x0008
+#define NV_FLAG_USE_BAR0_CFG           0x0010
+#define NV_FLAG_USES_MSI               0x0020
+#define NV_FLAG_S4_AVAILABLE           0x0040
+#define NV_FLAG_PASSTHRU               0x0080
+#define NV_FLAG_GVI_IN_SUSPEND         0x0100
+#define NV_FLAG_GVI                    0x0200
+#define NV_FLAG_GVI_INTR_EN            0x0400
+#define NV_FLAG_PERSISTENT_SW_STATE    0x0800
 
 #define NV_PM_APM_SUSPEND       0x0001
 #define NV_PM_APM_RESUME        0x0002
@@ -513,7 +520,7 @@ NvS32  NV_API_CALL  nv_free_kernel_mapping       (nv_state_t *, void *, void *,
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
-void*  NV_API_CALL  nv_get_adapter_state         (NvU16, NvU16);
+void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU16, NvU16);
 
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 
@@ -542,16 +549,18 @@ void   NV_API_CALL  nv_acpi_methods_init         (NvU32 *);
 void   NV_API_CALL  nv_acpi_methods_uninit       (void);
 
 RM_STATUS  NV_API_CALL  nv_acpi_method           (NvU32, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
-RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
+RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
 void*  NV_API_CALL  nv_get_smu_state             (void); 
 
 #ifdef NV_USER_MAP
 #include "nv-map.h"
 #else /* NV_USER_MAP */
-#define NV_MAP_USER_SPACE(status, nv, va, sz, pr, hclient, hparent, hobject)  do { } while (0)
-#define NV_UNMAP_USER_SPACE(nv, va)  do { } while (0)
-#define NV_UNMAP_OBJECT_USER_SPACE(nv, hclient, hparent, hobject)  do { } while (0)
-#define NV_RELEASE_USERMAP_LIST(nvl) do { } while (0)
+#define NV_MAP_USER_SPACE(nv, file, va, sz, pr, hclient, hparent, hobject)  do { } while (0)
+#define NV_UNMAP_USER_SPACE(nv, file, hclient, hparent, hobject, va)  do { } while (0)
+#define NV_UNMAP_OBJECT_USER_SPACE(nv, file, hclient, hparent, hobject)  do { } while (0)
+#define NV_RELEASE_USERMAP_LIST(nvl,fp) do { } while (0)
+#define NV_FILE_REFERENCE(file_p) ((void *) (file_p))
+#define NV_GET_VOID_FILE_PRIVATE(vfp_p) (NV_GET_FILE_PRIVATE(((struct file * ) (vfp_p))))
 #endif /* NV_USER_MAP */
 
 /*
@@ -596,7 +605,7 @@ RM_STATUS  NV_API_CALL  rm_read_registry_binary  (nv_stack_t *, nv_state_t *, Nv
 RM_STATUS  NV_API_CALL  rm_write_registry_binary (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32);
 
 RM_STATUS  NV_API_CALL  rm_run_rc_callback       (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_get_device_name       (nv_stack_t *, nv_state_t *, NvU32, NvU32, NvU8*);
+RM_STATUS  NV_API_CALL  rm_get_device_name       (nv_stack_t *, nv_state_t *, NvU16, NvU32, NvU8*);
 
 NvU64      NV_API_CALL  nv_rdtsc                 (void);
 
@@ -624,6 +633,8 @@ RM_STATUS  NV_API_CALL  rm_shutdown_smu           (nv_stack_t *, nv_smu_state_t
 RM_STATUS  NV_API_CALL  rm_suspend_smu            (nv_stack_t *);
 RM_STATUS  NV_API_CALL  rm_resume_smu             (nv_stack_t *);
 
+void       NV_API_CALL  rm_disable_gpu_state_persistence    (nv_stack_t *sp, nv_state_t *);
+
 #define rm_disable_interrupts(sp) rm_set_interrupts((sp),FALSE)
 #define rm_enable_interrupts(sp)  rm_set_interrupts((sp),TRUE)
 
