@@ -26,7 +26,7 @@ nv_state_t nvidia_ctl_state;
 int nvidia_attach(device_t dev)
 {
     int status;
-    U032 i;
+    NvU32 i;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
@@ -35,11 +35,11 @@ int nvidia_attach(device_t dev)
 
     nv->os_state         = sc;
     nv->flags            = 0;
+    nv->domain           = pci_get_domain(dev);
     nv->bus              = pci_get_bus(dev);
     nv->slot             = pci_get_slot(dev);
     nv->vendor_id        = pci_get_vendor(dev);
     nv->device_id        = pci_get_device(dev);
-    nv->interrupt_line   = pci_get_irq(dev);
     nv->handle           = dev;
 
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
@@ -106,6 +106,8 @@ int nvidia_attach(device_t dev)
     if ((status = nvidia_ctl_attach()) != 0)
         return status;
 
+    nv->interrupt_line = rman_get_start(sc->irq);
+
     nv_sysctl_init(nv);
 
     return 0;
@@ -212,9 +214,16 @@ int nvidia_resume(device_t dev)
 
 int nvidia_alloc_hardware(device_t dev)
 {
-    int error = 0;
+    int status = 0;
     struct nvidia_softc *sc;
-    U032 flags, i;
+    NvU32 flags, i;
+    NvU32 enable_msi = 0;
+    int count;
+    nv_stack_t *sp;
+
+    NV_UMA_ZONE_ALLOC_STACK(sp);
+    if (sp == NULL)
+        return ENOMEM;
 
     sc = device_get_softc(dev);
     sc->dev = dev;
@@ -237,28 +246,35 @@ int nvidia_alloc_hardware(device_t dev)
             device_printf(dev,
                 "NVRM: NVIDIA MEM resource alloc failed, BAR%d @ 0x%02x.\n",
                 i, sc->nv_state->bars[i].offset);
-            error = ENXIO;
+            status = ENXIO;
             goto failed;
         }
         sc->BAR_recs[i] = res;
     }
 
+    if ((rm_read_registry_dword(sp, NULL, "NVreg",
+            "EnableMSI", &enable_msi) == RM_OK) && (enable_msi != 0)) {
+        count = pci_msi_count(dev);
+        if ((count == 1) && (pci_alloc_msi(dev, &count) == 0))
+            sc->irq_rid = 1;
+    }
     flags = RF_SHAREABLE | RF_ACTIVE;
     sc->irq = bus_alloc_resource_any(dev, SYS_RES_IRQ, &sc->irq_rid, flags);
     if (sc->irq == NULL) {
         device_printf(dev, "NVRM: NVIDIA IRQ resource alloc failed.\n");
-        error = ENXIO;
+        status = ENXIO;
         goto failed;
     }
 
 failed:
-    return (error);
+    NV_UMA_ZONE_FREE_STACK(sp);
+    return status;
 }
 
 void nvidia_free_hardware(device_t dev)
 {
     struct nvidia_softc *sc;
-    U032 i;
+    NvU32 i;
 
     sc = device_get_softc(dev);
 
@@ -266,6 +282,8 @@ void nvidia_free_hardware(device_t dev)
         bus_release_resource(dev, SYS_RES_MEMORY, sc->BAR_rids[i], sc->BAR_recs[i]);
     if (sc->irq != NULL)
         bus_release_resource(dev, SYS_RES_IRQ, sc->irq_rid, sc->irq);
+    if (sc->irq_rid != 0)
+        pci_release_msi(dev);
     if (sc->iop != NULL)
         bus_release_resource(dev, SYS_RES_IOPORT, sc->iop_rid, sc->iop);
 }
@@ -274,7 +292,7 @@ void nvidia_intr(void *xsc)
 {
     struct nvidia_softc *sc;
     nv_state_t *nv;
-    U032 run_bottom_half = 0;
+    NvU32 run_bottom_half = 0;
     nv_stack_t *sp;
 
     sc = (struct nvidia_softc *) xsc;
@@ -347,10 +365,12 @@ int nvidia_get_card_info(struct nv_ioctl_card_info *ci)
         nv = sc->nv_state;
 
         ci[i].flags          = NV_IOCTL_CARD_INFO_FLAG_PRESENT;
+        ci[i].domain         = nv->domain;
         ci[i].bus            = nv->bus;
         ci[i].slot           = nv->slot;
         ci[i].vendor_id      = nv->vendor_id;
         ci[i].device_id      = nv->device_id;
+        ci[i].gpu_id         = nv->gpu_id;
         ci[i].interrupt_line = nv->interrupt_line;
         ci[i].fb_address     = nv->fb->address;
         ci[i].fb_size        = nv->fb->size;
@@ -685,7 +705,7 @@ int nvidia_modevent(
 
 
 #ifdef NV_SUPPORT_OS_AGP
-S032 nv_os_agp_init(
+NvS32 nv_os_agp_init(
     nv_stack_t *sp,
     nv_state_t *nv,
     NvU64 *base,
@@ -696,11 +716,11 @@ S032 nv_os_agp_init(
     struct nvidia_softc *sc = nv->os_state;
     struct agp_info ai;
 
-    U032 mode = 0;
-    U032 fw   = 0;
-    U032 sba  = 0;
-    U032 rate = (8 | 4 | 2 | 1);
-    U032 size = 0;
+    NvU32 mode = 0;
+    NvU32 fw   = 0;
+    NvU32 sba  = 0;
+    NvU32 rate = (8 | 4 | 2 | 1);
+    NvU32 size = 0;
 
     sc->agp_dev = agp_find_device();
     if (!sc->agp_dev) {
@@ -772,7 +792,7 @@ S032 nv_os_agp_init(
     return 0;
 }
 
-S032 nv_os_agp_teardown(
+NvS32 nv_os_agp_teardown(
     nv_stack_t *sp,
     nv_state_t *nv
 )
@@ -796,7 +816,7 @@ RM_STATUS NV_API_CALL nv_agp_init(
     nv_state_t *nv,
     NvU64 *base,
     NvU64 *limit,
-    U032 config
+    NvU32 config
 )
 {
     struct nvidia_softc *sc = nv->os_state;
@@ -932,7 +952,7 @@ RM_STATUS NV_API_CALL nv_agp_teardown(nv_state_t *nv)
     return status;
 }
 
-S032 NV_API_CALL nv_no_incoherent_mappings(void)
+NvS32 NV_API_CALL nv_no_incoherent_mappings(void)
 {
     return 1;
 }
@@ -952,8 +972,8 @@ void nv_unlock_api(nv_state_t *nv)
 void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
-    U032 hObject,
-    U032 index
+    NvU32 hObject,
+    NvU32 index
 )
 {
     struct nvidia_filep *filep = event->file;
@@ -974,11 +994,11 @@ void NV_API_CALL nv_post_event(
     selwakeup(&filep->event_rsel);
 }
 
-S032 NV_API_CALL nv_get_event(
+NvS32 NV_API_CALL nv_get_event(
     nv_state_t *nv,
     void *file,
     nv_event_t *event,
-    U032 *pending
+    NvU32 *pending
 )
 {
     struct nvidia_filep *filep = file;
@@ -1006,7 +1026,7 @@ S032 NV_API_CALL nv_get_event(
 void* NV_API_CALL nv_alloc_kernel_mapping(
     nv_state_t *nv,
     NvU64 address,
-    U032 size,
+    NvU32 size,
     void **private
 )
 {
@@ -1070,7 +1090,7 @@ found:
     return (void *)(virtual_address + offset);
 }
 
-S032 NV_API_CALL nv_free_kernel_mapping(
+NvS32 NV_API_CALL nv_free_kernel_mapping(
     nv_state_t *nv,
     void *address,
     void *private,
@@ -1090,10 +1110,10 @@ S032 NV_API_CALL nv_free_kernel_mapping(
     return RM_OK;
 }
 
-S032 nv_alloc_contig_pages(
+NvS32 nv_alloc_contig_pages(
     nv_state_t *nv,
-    U032 count,
-    U032 cache_type,
+    NvU32 count,
+    NvU32 cache_type,
     NvU64 *pte_array,
     void **private
 )
@@ -1102,7 +1122,7 @@ S032 nv_alloc_contig_pages(
     struct nvidia_softc *sc = nv->os_state;
     vm_memattr_t attr;
     vm_offset_t address;
-    U032 size = (count * PAGE_SIZE);
+    NvU32 size = (count * PAGE_SIZE);
     int status;
 
     switch (cache_type) {
@@ -1200,7 +1220,7 @@ failed:
     return status;
 }
 
-S032 nv_free_contig_pages(
+NvS32 nv_free_contig_pages(
     nv_state_t *nv,
     void *private
 )
@@ -1226,10 +1246,10 @@ S032 nv_free_contig_pages(
     return 0;
 }
 
-S032 nv_alloc_system_pages(
+NvS32 nv_alloc_system_pages(
     nv_state_t  *nv,
-    U032 count,
-    U032 cache_type,
+    NvU32 count,
+    NvU32 cache_type,
     NvU64 *pte_array,
     void **private
 )
@@ -1301,9 +1321,6 @@ S032 nv_alloc_system_pages(
 
     for (i = 0; i < count; i++) {
         pte_array[i] = at->pte_array[i].physical_address;
-        vm_page_lock_queues();
-        vm_page_wire(PHYS_TO_VM_PAGE(pte_array[i]));
-        vm_page_unlock_queues();
         sglist_append_phys(at->sg_list, pte_array[i], PAGE_SIZE);
     }
 
@@ -1346,7 +1363,7 @@ failed:
     return status;
 }
 
-S032 nv_free_system_pages(
+NvS32 nv_free_system_pages(
     nv_state_t *nv,
     void *private
 )
@@ -1365,9 +1382,6 @@ S032 nv_free_system_pages(
         os_flush_cpu_cache();
 
     for (i = 0; i < count; i++) {
-        vm_page_lock_queues();
-        vm_page_unwire(PHYS_TO_VM_PAGE(at->pte_array[i].physical_address), 0);
-        vm_page_unlock_queues();
         kmem_free(kernel_map,
                 at->pte_array[i].virtual_address, PAGE_SIZE);
         malloc_type_freed(M_NVIDIA, PAGE_SIZE);
@@ -1380,10 +1394,10 @@ S032 nv_free_system_pages(
 }
 
 #ifdef NV_SUPPORT_OS_AGP
-S032 nv_alloc_agp_pages(
+NvS32 nv_alloc_agp_pages(
     nv_state_t *nv,
-    U032 count,
-    U032 offset,
+    NvU32 count,
+    NvU32 offset,
     void **private
 )
 {
@@ -1418,11 +1432,11 @@ S032 nv_alloc_agp_pages(
     return 0;
 }
 
-S032 nv_free_agp_pages(
+NvS32 nv_free_agp_pages(
     nv_state_t *nv,
-    U032 count,
+    NvU32 count,
     void *private,
-    U032 *offset
+    NvU32 *offset
 )
 {
     void *handle = private;
@@ -1450,9 +1464,9 @@ S032 nv_free_agp_pages(
 
 RM_STATUS NV_API_CALL nv_alias_pages(
     nv_state_t *nv,
-    U032 page_cnt,
-    U032 contiguous,
-    U032 cache_type,
+    NvU32 page_cnt,
+    NvU32 contiguous,
+    NvU32 cache_type,
     NvU64 guest_id,
     NvU64 *pte_array,
     void **priv_data
@@ -1474,15 +1488,15 @@ RM_STATUS NV_API_CALL nv_guest_pfn_list(
 
 RM_STATUS NV_API_CALL nv_alloc_pages(
     nv_state_t *nv,
-    U032 count,
-    U032 alloc_type_agp,
-    U032 alloc_type_contiguous,
-    U032 cache_type,
+    NvU32 count,
+    NvU32 alloc_type_agp,
+    NvU32 alloc_type_contiguous,
+    NvU32 cache_type,
     NvU64 *pte_array,
     void **private
 )
 {
-    U032 offset;
+    NvU32 offset;
     RM_STATUS status = RM_ERR_NO_FREE_MEM;
     nv_stack_t *sp = NULL;
 
@@ -1543,10 +1557,10 @@ failed:
 
 RM_STATUS NV_API_CALL nv_free_pages(
     nv_state_t *nv,
-    U032 count,
-    U032 alloc_type_agp,
-    U032 alloc_type_contiguous,
-    U032 cache_type,
+    NvU32 count,
+    NvU32 alloc_type_agp,
+    NvU32 alloc_type_contiguous,
+    NvU32 cache_type,
     void *private
 )
 {
@@ -1563,7 +1577,7 @@ RM_STATUS NV_API_CALL nv_free_pages(
 
 #ifdef NV_SUPPORT_OS_AGP
         if (NV_OSAGP_ENABLED(nv)) {
-            U032 offset;
+            NvU32 offset;
 
             if (nv_free_agp_pages(nv, count, private, &offset) != 0)
                 goto failed;
@@ -1741,7 +1755,7 @@ int NV_API_CALL nv_stop_rc_timer(
 
 void NV_API_CALL nv_set_dma_address_size(
     nv_state_t *nv,
-    U032 phys_addr_bits
+    NvU32 phys_addr_bits
 )
 {
     struct nvidia_softc *sc = nv->os_state;
@@ -1753,8 +1767,9 @@ void NV_API_CALL nv_set_dma_address_size(
 }
 
 void* NV_API_CALL nv_get_adapter_state(
-    U016 bus,
-    U016 slot
+    NvU32 domain,
+    NvU16 bus,
+    NvU16 slot
 )
 {
     unsigned int i;
@@ -1767,8 +1782,10 @@ void* NV_API_CALL nv_get_adapter_state(
             continue;
         nv = sc->nv_state;
 
-        if (nv->bus == bus && nv->slot == slot)
+        if ((nv->domain == domain) &&
+                (nv->bus == bus) && (nv->slot == slot)) {
             return (void *) nv;
+        }
     }
 
     if (bus == 255 && slot == 255) {
@@ -1792,7 +1809,7 @@ void NV_API_CALL nv_verify_pci_config(
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, check_the_bars, FALSE, FALSE);
 }
 
-void NV_API_CALL nv_acpi_methods_init(U032 *handlesPresent)
+void NV_API_CALL nv_acpi_methods_init(NvU32 *handlesPresent)
 {
     *handlesPresent = 0;
 }
@@ -1803,28 +1820,29 @@ void NV_API_CALL nv_acpi_methods_uninit(void)
 }
 
 RM_STATUS NV_API_CALL nv_acpi_method(
-    U032 acpi_method,
-    U032 function,
-    U032 subFunction,
+    NvU32 acpi_method,
+    NvU32 function,
+    NvU32 subFunction,
     void *inParams,
-    U016 inParamSize,
-    U032 *outStatus,
-    void *outData,
-    U016 *outDataSize
+    NvU16 inParamSize,
+    NvU32 *outStatus,
+    void  *outData,
+    NvU16 *outDataSize
 )
 {
     return RM_ERR_NOT_SUPPORTED;
 }
 
 RM_STATUS NV_API_CALL nv_acpi_dsm_method(
-    U008 *pAcpiDsmGuid,
-    U032 acpiDsmRev,
-    U032 acpiDsmSubFunction,
-    void *pInParams,
-    U016 inParamSize,
-    U032 *outStatus,
-    void *pOutData,
-    U016 *pSize
+    nv_state_t *nv,
+    NvU8 *pAcpiDsmGuid,
+    NvU32 acpiDsmRev,
+    NvU32 acpiDsmSubFunction,
+    void  *pInParams,
+    NvU16 inParamSize,
+    NvU32 *outStatus,
+    void  *pOutData,
+    NvU16 *pSize
 )
 {
     return RM_ERR_NOT_SUPPORTED;
