@@ -22,9 +22,9 @@ struct sysctl_oid *oid_registry;
 static char *option_string = NULL;
 
 static void*  nvidia_find_bridge     (void);
-static U032   nvidia_dev_agp_cmd     (device_t dev);
-static U032   nvidia_dev_agp_status  (device_t dev);
-static U032   nvidia_sys_agp_cmd     (device_t dev);
+static NvU32  nvidia_dev_agp_cmd     (device_t dev);
+static NvU32  nvidia_dev_agp_status  (device_t dev);
+static NvU32  nvidia_sys_agp_cmd     (device_t dev);
 
 void nvidia_sysctl_init(void)
 {
@@ -153,10 +153,10 @@ void nvidia_sysctl_exit(void)
 }
 
 
-static U032 nvidia_dev_agp_cmd(device_t dev)
+static NvU32 nvidia_dev_agp_cmd(device_t dev)
 {
-    U008 cap_ptr;
-    U032 tmp;
+    NvU8  cap_ptr;
+    NvU32 tmp;
 
     cap_ptr = nvidia_pci_find_capability(dev, PCIR_CAP_ID_AGP);
     tmp = pci_read_config(dev, cap_ptr + 8, 4);
@@ -164,10 +164,10 @@ static U032 nvidia_dev_agp_cmd(device_t dev)
     return tmp;
 }
 
-static U032 nvidia_dev_agp_status(device_t dev)
+static NvU32 nvidia_dev_agp_status(device_t dev)
 {
-    U008 cap_ptr;
-    U032 tmp;
+    NvU8  cap_ptr;
+    NvU32 tmp;
 
     cap_ptr = nvidia_pci_find_capability(dev, PCIR_CAP_ID_AGP);
     tmp = pci_read_config(dev, cap_ptr + 4, 4);
@@ -175,9 +175,9 @@ static U032 nvidia_dev_agp_status(device_t dev)
     return tmp;
 }
 
-static U032 nvidia_sys_agp_cmd(device_t dev)
+static NvU32 nvidia_sys_agp_cmd(device_t dev)
 {
-    U032 tmp;
+    NvU32 tmp;
 
     tmp = nvidia_dev_agp_cmd(dev);
     tmp &= nvidia_dev_agp_cmd(nvidia_find_bridge());
@@ -187,10 +187,10 @@ static U032 nvidia_sys_agp_cmd(device_t dev)
 
 static void* nvidia_find_bridge(void)
 {
-    U008 hdrtype;
-    U032 bus;
-    U032 device;
-    U032 func;
+    NvU8  hdrtype;
+    NvU32 bus;
+    NvU32 device;
+    NvU32 func;
 
     device_t dev;
 
@@ -251,7 +251,7 @@ int nvidia_sysctl_dev_model(SYSCTL_HANDLER_ARGS)
     nv_stack_t *sp;
 
     char model_name[NV_DEVICE_NAME_LENGTH+1];
-    U016 id = nv->device_id;
+    NvU16 id = nv->device_id;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL)
@@ -272,8 +272,8 @@ int nvidia_sysctl_dev_vbios(SYSCTL_HANDLER_ARGS)
     nv_state_t *nv = arg1;
     nv_stack_t *sp;
 
-    U032 vbios[5];
-    U008 vbios_version[16];
+    NvU32 vbios[5];
+    NvU8  vbios_version[16];
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
     if (sp == NULL)
@@ -299,7 +299,7 @@ int nvidia_sysctl_dev_vbios(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_bus_type(SYSCTL_HANDLER_ARGS)
 {
     struct nvidia_softc *sc = arg1;
-    U008 bus_type[4];
+    NvU8 bus_type[4];
 
     if (nvidia_pci_find_capability(sc->dev, PCIR_CAP_ID_AGP) != 0)
         sprintf(bus_type, "AGP");
@@ -361,9 +361,9 @@ int nvidia_sysctl_registry_dwords(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_rates(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_rates[16];
+    NvU8 agp_rates[16];
 
-    U032 tmp = nvidia_dev_agp_status(dev);
+    NvU32 tmp = nvidia_dev_agp_status(dev);
 
     if ((tmp & 0x08) != 0)
         tmp = (tmp & 0x07) << 2;
@@ -380,7 +380,7 @@ int nvidia_sysctl_agp_rates(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_fw(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_fw[16];
+    NvU8 agp_fw[16];
 
     sprintf(agp_fw, "%ssupported",
         ((nvidia_dev_agp_status(dev) & 0x10) == 0x10) ? "" : "not ");
@@ -391,7 +391,7 @@ int nvidia_sysctl_agp_fw(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_sba(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_sba[16];
+    NvU8 agp_sba[16];
 
     sprintf(agp_sba, "%ssupported",
         ((nvidia_dev_agp_status(dev) & 0x200) == 0x200) ? "" : "not ");
@@ -402,7 +402,7 @@ int nvidia_sysctl_agp_sba(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_registers(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_registers[24];
+    NvU8 agp_registers[24];
 
     sprintf(agp_registers, "0x%08x:0x%08x",
         nvidia_dev_agp_status(dev), nvidia_dev_agp_cmd(dev));
@@ -413,7 +413,7 @@ int nvidia_sysctl_agp_registers(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_driver(SYSCTL_HANDLER_ARGS)
 {
     nv_state_t *nv = arg1;
-    U008 agp_driver[24];
+    NvU8 agp_driver[24];
 
     switch (nv->agp_config) {
         case NVOS_AGP_CONFIG_DISABLE_AGP:
@@ -433,9 +433,9 @@ int nvidia_sysctl_agp_driver(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_rate_status(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_rate[16];
+    NvU8 agp_rate[16];
 
-    U032 tmp = nvidia_sys_agp_cmd(dev);
+    NvU32 tmp = nvidia_sys_agp_cmd(dev);
 
     if ((tmp & 0x100) && (tmp &= 0x07)) {
         sprintf(agp_rate, "%1dx",
@@ -450,9 +450,9 @@ int nvidia_sysctl_agp_rate_status(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_fw_status(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_fw[16];
+    NvU8 agp_fw[16];
 
-    U032 tmp = nvidia_sys_agp_cmd(dev);
+    NvU32 tmp = nvidia_sys_agp_cmd(dev);
 
     if ((tmp & 0x100) == 0x100) {
         sprintf(agp_fw, "%s",
@@ -467,9 +467,9 @@ int nvidia_sysctl_agp_fw_status(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_sba_status(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_sba[16];
+    NvU8 agp_sba[16];
 
-    U032 tmp = nvidia_sys_agp_cmd(dev);
+    NvU32 tmp = nvidia_sys_agp_cmd(dev);
 
     if ((tmp & 0x100) == 0x100) {
         sprintf(agp_sba, "%s",
@@ -484,7 +484,7 @@ int nvidia_sysctl_agp_sba_status(SYSCTL_HANDLER_ARGS)
 int nvidia_sysctl_agp_status(SYSCTL_HANDLER_ARGS)
 {
     device_t dev = arg1;
-    U008 agp_cmd[16];
+    NvU8 agp_cmd[16];
 
     sprintf(agp_cmd, "%s",
         (nvidia_sys_agp_cmd(dev) & 0x100) ? "enabled" : "disabled");
