@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-1998 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2010 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -126,8 +126,9 @@ typedef          __int64   NvS64; /* 2^-63 to 2^63-1                        */
 #endif
 
 /* Boolean type */
-enum { NV_FALSE = 0, NV_TRUE = 1 };
 typedef NvU8 NvBool;
+#define NV_TRUE           ((NvBool)(0 == 0))
+#define NV_FALSE          ((NvBool)(0 != 0))
 
 /* Macros to extract the low and high parts of a 64-bit unsigned integer */
 /* Also designed to work if someone happens to pass in a 32-bit integer */
@@ -216,16 +217,16 @@ typedef unsigned char *PUCHAR;
 
 #define NV_S8_MIN       ((NvS8) -128)
 #define NV_S8_MAX       ((NvS8) +127)
-#define NV_U8_MIN       ((NvU8) +0)
-#define NV_U8_MAX       ((NvU8) +255)
+#define NV_U8_MIN       ((NvU8) +0u)
+#define NV_U8_MAX       ((NvU8) +255u)
 #define NV_S16_MIN      ((NvS16)-32768)
 #define NV_S16_MAX      ((NvS16)+32767)
-#define NV_U16_MIN      ((NvU16)+0)
-#define NV_U16_MAX      ((NvU16)+65535)
+#define NV_U16_MIN      ((NvU16)+0u)
+#define NV_U16_MAX      ((NvU16)+65535u)
 #define NV_S32_MIN      ((NvS32)-2147483648)
 #define NV_S32_MAX      ((NvS32)+2147483647)
-#define NV_U32_MIN      ((NvU32)+0)
-#define NV_U32_MAX      ((NvU32)+4294967295)
+#define NV_U32_MIN      ((NvU32)+0u)
+#define NV_U32_MAX      ((NvU32)+4294967295u)
 
 #if !defined(NV_PTR)
     /* Supports 32bit libraries on Win64
@@ -333,6 +334,70 @@ typedef unsigned char *PUCHAR;
 
 #endif  // defined(NV_WINDOWS)
 
+/*!
+ * Fixed-point data types.
+ *
+ * These are all signed integer types with precision indicated in the naming of
+ * the form: NvFXP<num_bits_above_radix>_<num bits below radix>.  The actual
+ * size of the data type is calculated as num_bits_above_radix +
+ * num_bit_below_radix.
+ *
+ */
+typedef NvS16                                                        NvFXP11_5;
+typedef NvS16                                                        NvFXP4_12;
+typedef NvS16                                                         NvFXP8_8;
+typedef NvS32                                                       NvFXP16_16;
+typedef NvS32                                                        NvFXP24_8;
+
+/*!
+ * Utility macros for converting between signed integers and fixed-point
+ * notation.
+ *
+ * - _SCALED:
+ *   For integer -> fixed-point we add handling divisors to represent
+ *   non-integer values.
+ *
+ * - _ROUNDED:
+ *   For fixed-point -> integer we add rounding to integer values. 
+ */
+#define NV_TYPES_FXP_INTEGER_SIGN(x, y)                 ((x)+(y)-1):((x)+(y)-1)
+#define NV_TYPES_FXP_INTEGER_SIGN_NEGATIVE                           0x00000001
+#define NV_TYPES_FXP_INTEGER_SIGN_POSITIVE                           0x00000000
+#define NV_TYPES_FXP_SIGNED_INTEGER(x, y)                       ((x)+(y)-1):(y)
+#define NV_TYPES_FXP_SIGNED_INTEGER_MAX(x, y)                      (BIT((x))-1)
+#define NV_TYPES_FXP_SIGNED_INTEGER_MIN(x, y)                   (~(BIT((x))-1))
+#define NV_TYPES_FXP_FRACTIONAL(x, y)                                 ((y)-1):0
+#define NV_TYPES_FXP_FRACTIONAL_MSB(x, y)                       ((y)-1):((y)-1)
+#define NV_TYPES_FXP_FRACTIONAL_MSB_ONE(x, y)                        0x00000001
+#define NV_TYPES_FXP_FRACTIONAL_MSB_ZERO(x, y)                       0x00000000
+#define NV_TYPES_FXP_S32_SIGN_EXTENSION(x, y)                            31:(x)
+#define NV_TYPES_FXP_S32_SIGN_EXTENSION_POSITIVE(x, y)               0x00000000
+#define NV_TYPES_FXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)          (BIT(32-(x))-1)
+
+#define NV_TYPES_S32_TO_FXP_X_Y(x, y, integer)                                \
+    ((NvFXP##x##_##y) (((NvS32) (integer)) <<                                 \
+                        DRF_SHIFT(NV_TYPES_FXP_SIGNED_INTEGER((x), (y)))))
+
+#define NV_TYPES_S32_TO_FXP_X_Y_SCALED(x, y, integer, scale)                  \
+    ((NvFXP##x##_##y) (((((NvS32) (integer)) <<                               \
+                        DRF_SHIFT(NV_TYPES_FXP_SIGNED_INTEGER((x), (y)))) +   \
+                      ((scale) / 2)) /                                        \
+                     (scale)))
+
+#define NV_TYPES_FXP_X_Y_TO_S32(x, y, fxp)                                    \
+    ((NvS32) ((DRF_VAL(_TYPES, _FXP, _SIGNED_INTEGER((x), (y)),               \
+                    ((NvFXP##x##_##y) (fxp)))) |                              \
+              ((DRF_VAL(_TYPES, _FXP, _INTEGER_SIGN((x), (y)), (fxp)) ==      \
+                    NV_TYPES_FXP_INTEGER_SIGN_NEGATIVE) ?                     \
+                DRF_NUM(_TYPES, _FXP, _S32_SIGN_EXTENSION((x), (y)),          \
+                    NV_TYPES_FXP_S32_SIGN_EXTENSION_NEGATIVE((x), (y))) :     \
+                DRF_NUM(_TYPES, _FXP, _S32_SIGN_EXTENSION((x), (y)),          \
+                    NV_TYPES_FXP_S32_SIGN_EXTENSION_POSITIVE((x), (y))))))
+
+#define NV_TYPES_FXP_X_Y_TO_S32_ROUNDED(x, y, fxp)                            \
+    ((NV_TYPES_FXP_X_Y_TO_S32(x, y, (fxp))) +                                 \
+     (DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)), (fxp))))
+
 
 #include "xapi-sdk.h"       /* XAPIGEN sdk macros for C */
 
