@@ -77,7 +77,7 @@ RM_STATUS   NV_API_CALL  os_memcpy_from_user         (void *, const void *, NvU3
 RM_STATUS   NV_API_CALL  os_memcpy_to_user           (void *, const void *, NvU32);
 void*       NV_API_CALL  os_mem_set                  (void *, NvU8, NvU32);
 NvS32       NV_API_CALL  os_mem_cmp                  (const NvU8 *, const NvU8 *, NvU32);
-void*       NV_API_CALL  os_pci_init_handle          (NvU8, NvU8, NvU8, NvU16 *, NvU16 *);
+void*       NV_API_CALL  os_pci_init_handle          (NvU32, NvU8, NvU8, NvU8, NvU16 *, NvU16 *);
 NvU8        NV_API_CALL  os_pci_read_byte            (void *, NvU8);
 NvU16       NV_API_CALL  os_pci_read_word            (void *, NvU8);
 NvU32       NV_API_CALL  os_pci_read_dword           (void *, NvU8);
